<?php
/**
 * A XML compacting decorator class for XML parsers
 *
 * @author		Roland Haeder <webmaster@ship-simu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2011 Core Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.ship-simu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class XmlCompactorDecorator extends BaseDecorator implements Parseable {
	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	protected function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);
	}

	/**
	 * Creates an instance of the class Parser and prepares it for usage
	 *
	 * @param	$innerParserInstance	A Parseable instance
	 * @return	$parserInstance		An instance of this parser
	 */
	public static final function createXmlCompactorDecorator (Parseable $innerParserInstance) {
		// Get a new instance
		$parserInstance = new XmlCompactorDecorator();

		// Get a new decorator instance for the template engine
		$templateInstance = ObjectFactory::createObjectByConfiguredName('deco_xml_rewriter_template_class', array($innerParserInstance->getTemplateInstance()));

		// Re-set the parser's template instance to the decorator instance
		$innerParserInstance->setTemplateInstance($templateInstance);

		// Set the inner parser instance
		$parserInstance->setParserInstance($innerParserInstance);

		// Return the prepared instance
		return $parserInstance;
	}

	/**
	 * Parses the given XML content
	 *
	 * @param	$content	Valid XML content
	 * @return	void
	 * @throws	XmlCompactorDecoratorException	If an XML error was found
	 */
	public function parseXmlContent ($content) {
		// Remove all comments for better compacting
		$content = $this->getParserInstance()->getTemplateInstance()->compactContent($content);

		// Parse the content
		$this->getParserInstance()->parseXmlContent($content);
	}
}

// [EOF]
?>
