<?php
/**
 * A factory class for XML template engines. All instances generated by this
 * factory does have language support disabled and XML-compacting enabled (to
 * save memory/network load).
 *
 * @author		Roland Haeder <webmaster@ship-simu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2011 Hub Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.ship-simu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class XmlTemplateEngineFactory extends ObjectFactory {
	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	protected function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);
	}

	/**
	 * Returns a singleton network package instance. If an instance is found in
	 * the registry it will be returned, else a new instance is created and
	 * stored in the same registry entry.
	 *
	 * @param	$configEntry		Config entry name for the template engine
	 * @return	$templateInstance	A template engine instance
	 */
	public static final function createXmlTemplateEngineInstance ($configEntry) {
		// Do we have an instance in the registry?
		if (Registry::getRegistry()->instanceExists($configEntry)) {
			// Then use this instance
			$templateInstance = Registry::getRegistry()->getInstance($configEntry);
		} else {
			// Now prepare the tags instance
			$templateInstance = ObjectFactory::createObjectByConfiguredName($configEntry);

			// Disable language support
			$templateInstance->enableLanguageSupport(false);

			/*
			 * Enable compacting/rewriting of the  XML to save bandwidth from XML
			 * comments. This is expensive and should be avoided in general.
			 */
			$templateInstance->enableXmlCompacting();

			// Set the instance in registry for further use
			Registry::getRegistry()->addInstance($configEntry, $templateInstance);
		}

		// Return the instance
		return $templateInstance;
	}
}

// [EOF]
?>
